#define MOZ_SOURCE_STAMP 820bc5bd3120853d611af1056f4a2b35528bb927
#define MOZ_SOURCE_REPO https://hg.mozilla.org/releases/mozilla-beta
#define MOZ_SOURCE_URL https://hg.mozilla.org/releases/mozilla-beta/rev/820bc5bd3120853d611af1056f4a2b35528bb927
